pub struct HeaderType {
pub version: HeaderVersion,
pub algorithm: Algorithm,
pub mode: Mode,
}Expand description
This is the Header’s type - it contains the specific details that are needed to decrypt the data
It contains the header’s version, the “mode” that was used to encrypt the data, and the algorithm used.
This needs to be manually created for encrypting data
Fields
version: HeaderVersionalgorithm: Algorithmmode: ModeAuto Trait Implementations
impl Freeze for HeaderType
impl RefUnwindSafe for HeaderType
impl Send for HeaderType
impl Sync for HeaderType
impl Unpin for HeaderType
impl UnsafeUnpin for HeaderType
impl UnwindSafe for HeaderType